@@ -1,19 +1,32 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
 
+#include "about.h"
+#include "help.h"
+
 #include <QProcess>
 #include <QtCore/QCoreApplication>
 #include <QDesktopServices>
 #include <QUrl>
 
 MainWindow::MainWindow(QWidget *parent)
-    : QMainWindow(parent), ui(new Ui::MainWindow), m_process(new QProcess(this))
+    : QMainWindow(parent), ui(new Ui::MainWindow),
+      about(0),
+      help(0),
+      m_process(new QProcess(this))
+
 {
     ui->setupUi(this);
+
+    setAttribute(Qt::WA_Maemo5StackedWindow);
+    about = new About(this);
+    help = new Help(this);
 }
 
 MainWindow::~MainWindow()
 {
+    if (about) delete (about);
+    if (help) delete (help);
     delete ui;
 }
 
@@ -76,7 +89,12 @@ void MainWindow::on_pushButtonStart_clicked()
     m_process->start("sh opt/tenminutecore/script/tenminutecore.sh");
 }
 
-void MainWindow::on_pushButtonHelp_clicked()
+void MainWindow::on_actionAbout_triggered()
 {
-    QDesktopServices::openUrl(QUrl("http://wiki.maemo.org/Tenminutecore#The_Exercises"));
+    about->show();
+}
+
+void MainWindow::on_actionHelp_triggered()
+{
+    help->show();
 }
