@@ -4,6 +4,9 @@
 #include <QtGui/QMainWindow>
 #include <QProcess>
 
+class About;
+class Help;
+
 namespace Ui {
     class MainWindow;
 }
@@ -29,10 +32,14 @@ public:
 private slots:
     void on_pushButtonStart_clicked();
 
-    void on_pushButtonHelp_clicked();
+    void on_actionAbout_triggered();
+
+    void on_actionHelp_triggered();
 
 private:
     Ui::MainWindow *ui;
+    About *about;
+    Help *help;
     QProcess *m_process;
 };
 
